package gongyinglian

import (
	"shylinux.com/x/ice"
	kit "shylinux.com/x/toolkits"

	"shylinux.com/x/enterprise/src/gongyinglian/model"
	"shylinux.com/x/enterprise/src/guanlixitong"
)

type Table struct {
	guanlixitong.Table
	list string `name:"list store_uid uid auto" role:"void"`
}

func (s Table) Inputs(m *ice.Message, arg ...string) {
	switch arg[0] {
	case model.USER_STORE_ROLE:
		s.InputsListRole(m, UserStoreRoleList, arg...)
	case model.STORE_TYPE:
		s.InputsList(m, StoreTypeList, arg...)
	case model.PRODUCT_TYPE:
		s.InputsList(m, ProductTypeList, arg...)
	case model.EXPENSE_TYPE:
		s.InputsList(m, ExpenseTypeList, arg...)
	case model.LOAN_TYPE:
		s.InputsList(m, LoanTypeList, arg...)
	case model.FROM_STORE_UID, model.TO_STORE_UID:
		m.Cmdy(userStore{}, m.Option(model.USER_UID)).Cut(model.STORE_UID, model.STORE_NAME).RenameAppend(model.STORE_UID, arg[0])
		m.DisplayInputKeyNameIconTitle()
	default:
		s.Table.Inputs(m, arg...)
	}
}
func (s Table) RewriteAppend(m *ice.Message, arg ...string) *ice.Message {
	m.RewriteAppend(func(value, key string, index int) string {
		switch key {
		case model.USER_STORE_ROLE:
			value = UserStoreRole(kit.Int(value)).String()
		case model.STORE_TYPE:
			value = StoreType(kit.Int(value)).String()
		case model.PRODUCT_TYPE:
			value = ProductType(kit.Int(value)).String()
		case model.ORDER_TYPE:
			value = OrderType(kit.Int(value)).String()
		case model.ORDER_STATUS:
			value = OrderStatus(kit.Int(value)).String()
		case model.PAYMENT_STATUS:
			value = PaymentStatus(kit.Int(value)).String()
		case model.EXPRESS_STATUS:
			value = ExpressStatus(kit.Int(value)).String()
		case model.RETURN_STATUS:
			value = ReturnStatus(kit.Int(value)).String()
		case model.REFUND_STATUS:
			value = RefundStatus(kit.Int(value)).String()
		case model.EXPENSE_TYPE:
			value = ExpenseType(kit.Int(value)).String()
		case model.LOAN_TYPE:
			value = LoanType(kit.Int(value)).String()
		case model.AMOUNT, model.PRICE:
			value = kit.Format("%0.2f", float64(kit.Int(value))/100)
		}
		return value
	})
	return s.Table.RewriteAppend(m)
}
func (s Table) CheckRole(m *ice.Message, arg ...string) *ice.Message {
	role := UserStoreRole(s.UserPlaceRole(m))
	m.WarnNotRight(!kit.IsIn(role.String(), append(arg, UserStoreCreator.String())...), role.String())
	return m
}
func (s Table) checkOrderRole(m *ice.Message, arg ...string) bool {
	user_uid := m.Option(model.USER_UID)
	msg := m.Cmd(Order{}, s.Select, "(from_store_uid = ? OR to_store_uid = ?) AND uid = ?", arg[0], arg[0], arg[1])
	if msg.Append(model.FROM_USER_UID) != "" && msg.Append(model.TO_USER_UID) != "" && user_uid != msg.Append(model.FROM_USER_UID) && user_uid != msg.Append(model.TO_USER_UID) {
		return false
	}
	return true
}
func (s Table) IsBoss(m *ice.Message) bool {
	return s.IsLeader(m)
}
func (s Table) IsWorker(m *ice.Message) bool {
	role := UserStoreRole(kit.Int(m.Option(model.USER_ROLE)))
	return role == UserStoreCreator || role == UserStoreWorker
}

type Tables struct{ Table }

func (s Tables) BeforeMigrate(m *ice.Message, arg ...string) {}

type Value struct {
	Table
	fields string `data:"name,info,user_uid"`
	create string `name:"create name info" role:"boss"`
	modify string `name:"modify name info" role:"boss"`
	remove string `name:"remove" role:"boss"`
}

func (s Value) Create(m *ice.Message, arg ...string) {
	s.ValueCreate(m, s.transPrice(m, arg...)...)
}
func (s Value) Modify(m *ice.Message, arg ...string) {
	s.ValueModify(m, s.transPrice(m, arg...)...)
}
func (s Value) List(m *ice.Message, arg ...string) {
	s.ValueList(m, arg).PushAction(s.Modify, s.Remove)
}
func (s Value) transPrice(m *ice.Message, arg ...string) []string {
	for i := 0; i < len(arg); i += 2 {
		switch arg[i] {
		case model.AMOUNT, model.PRICE:
			arg[i+1] = kit.Format(kit.Int(kit.Float(arg[i+1]) * 100))
		}
	}
	return arg
}

type Relative struct{ Table }

func (s Relative) List(m *ice.Message, arg ...string) {
	if !s.IsBoss(m) && !s.IsWorker(m) {
		return
	}
	order := Order{}
	s.Tables(m, Order{}).FieldsWithCreatedAT(m, m.CommandKey(),
		s.AS(model.TO_USER_UID, model.USER_UID), m.CommandKey()+"_"+model.STATUS,
		s.Key(order, model.AMOUNT), s.Key(order, model.TOTAL),
		model.COMPANY_UID, model.OPEN_ID, model.ORDER_UID,
	)
	if len(arg) == 1 {
		s.Select(m, model.FROM_STORE_UID, arg[0]).Action()
	} else if len(arg) == 2 {
		s.SelectDetail(m, model.FROM_STORE_UID, arg[0], s.Key(m.CommandKey(), model.UID), arg[1])
	} else {
		return
	}
	s.SelectJoinCompany(m)
	s.SelectJoinUser(m)
	m.Display(m.CommandKey() + ".js")
}
