package guanlixitong

import (
	"shylinux.com/x/ice"
	kit "shylinux.com/x/toolkits"

	"shylinux.com/x/enterprise/src/guanlixitong/model"
)

type recruitment struct {
	Table
	resume       resume
	fields       string `data:"title,degree,seniority,salary,content,total,count,recruitment_status,user_uid"`
	create       string `name:"create title* degree* seniority* salary* content* total*=1" role:"leader,worker"`
	modify       string `name:"modify content*" role:"leader,worker"`
	remove       string `name:"remove" role:"leader,worker"`
	start        string `name:"start" role:"leader"`
	stop         string `name:"stop" role:"leader"`
	resumeInsert string `name:"create name* info mobile* email degree*" role:"void"`
}

func (s recruitment) Inputs(m *ice.Message, arg ...string) {
	switch arg[0] {
	case model.TITLE:
		m.Push(arg[0], "高级销售")
		m.Push(arg[0], "中级销售")
		m.Push(arg[0], "初级销售")
	case model.SENIORITY:
		m.Push(arg[0], "10年以上")
		m.Push(arg[0], "5-10年")
		m.Push(arg[0], "3-5年")
		m.Push(arg[0], "1-3年")
		m.Push(arg[0], "应届生")
		m.Push(arg[0], "在校生")
	case model.SALARY:
		m.Push(arg[0], "45K以上")
		m.Push(arg[0], "35-45K")
		m.Push(arg[0], "25-35K")
		m.Push(arg[0], "15-25K")
		m.Push(arg[0], "15K以下")
	case model.CONTENT:
	default:
		s.Table.Inputs(m, arg...)
	}
}
func (s recruitment) List(m *ice.Message, arg ...string) {
	msg := m.Spawn()
	list := map[string]int{}
	s.Fields(msg, model.RECRUITMENT_UID, "count(*) AS `count`").Groups(msg, model.RECRUITMENT_UID)
	msg = msg.Cmd(s.resume, s.Select, m.OptionSimple(model.GROUP_UID, model.USER_UID))
	msg.Table(func(value ice.Maps) { list[value[model.RECRUITMENT_UID]] = kit.Int(value[model.COUNT]) })
	s.ValueList(m, arg).Table(func(value ice.Maps) {
		count := list[value[model.UID]]
		button := []ice.Any{}
		switch RecruitmentStatus(kit.Int(value[model.RECRUITMENT_STATUS])) {
		case RecruitmentCreate:
			if s.IsLeader(m) {
				button = append(button, s.Start)
			}
			if s.IsWorker(m) {
				button = append(button, s.Modify, s.Remove)
			}
		case RecruitmentStart:
			if count == 0 || s.IsWorker(m) {
				button = append(button, s.ResumeInsert)
			}
			if m.Option(model.MARKET_UID) == "" {
				if s.IsLeader(m) {
					button = append(button, s.MarketInsert, s.Modify, s.Stop)
				} else if s.IsWorker(m) {
					button = append(button, s.Modify)
				}
			}
		}
		m.PushButton(button...)
	}).Display("")
	kit.If(m.Length() == 0, func() { s.Button(m.SetResult(), "") })
}
func (s recruitment) Start(m *ice.Message, arg ...string) {
	s.ValueModify(m, model.STATUS, kit.Format(RecruitmentStart))
}
func (s recruitment) Stop(m *ice.Message, arg ...string) {
	s.ValueModify(m, model.STATUS, kit.Format(RecruitmentStop))
}
func (s recruitment) ResumeInsert(m *ice.Message, arg ...string) {
	if m.Warn(m.Cmd(s.resume, s.Select, model.RECRUITMENT_UID, m.Option(model.UID), m.OptionSimple(model.MOBILE)).Length() > 0, "已经投过简历，请勿重复投递，投递") {
		return
	}
	m.Cmdy(s.resume, s.Insert, arg, m.OptionSimple(model.GROUP_UID, model.USER_UID), model.RECRUITMENT_UID, m.Option(model.UID))
}

func init() { ice.TeamCtxCmd(recruitment{}) }

type RecruitmentStatus int

const (
	RecruitmentCreate RecruitmentStatus = iota
	RecruitmentStart
	RecruitmentStop
)

var RecruitmentStatusList = map[RecruitmentStatus]string{
	RecruitmentCreate: "create",
	RecruitmentStart:  "start",
	RecruitmentStop:   "stop",
}

func (s RecruitmentStatus) String() string { return RecruitmentStatusList[s] }
